summaryrefslogtreecommitdiffstats
path: root/core/divelist.c
diff options
context:
space:
mode:
Diffstat (limited to 'core/divelist.c')
-rw-r--r--core/divelist.c9
1 files changed, 8 insertions, 1 deletions
diff --git a/core/divelist.c b/core/divelist.c
index 0b772f201..8e1ba1628 100644
--- a/core/divelist.c
+++ b/core/divelist.c
@@ -1365,7 +1365,7 @@ static void insert_dive(struct dive_table *table, struct dive *d)
}
/*
* Clear a dive_table and a trip_table. Think about generating these with macros.
*/
void clear_table(struct dive_table *table)
{
@@ -1381,6 +1381,13 @@ static void clear_trip_table(struct trip_table *table)
table->nr = 0;
}
+void clear_dive_site_table(struct dive_site_table *ds_table)
+{
+ for (int i = 0; i < ds_table->nr; i++)
+ free_dive_site(ds_table->dive_sites[i]);
+ ds_table->nr = 0;
+}
+
/*
* Try to merge a new dive into the dive at position idx. Return
* true on success. On success, the old dive will be added to the
@@ -1365,7 +1365,7 @@ static void insert_dive(struct dive_table *table, struct dive *d)
}
/*
- * Clear a dive_table and a trip_table. Think about generating these with macros.
+ * Clear a dive_table, trip_table and dive_site_table. Think about generating these with macros.
*/
void clear_table(struct dive_table *table)